[![PyPI version fury.io](https://badge.fury.io/py/py4etrics.svg)](https://pypi.python.org/pypi/py4etrics/)
[![CodeQL](https://github.com/Py4Etrics/py4etrics/actions/workflows/codeql-analysis.yml/badge.svg)](https://github.com/Py4Etrics/py4etrics/actions?query=workflow%codeql-analysis)
[![Downloads](https://static.pepy.tech/personalized-badge/py4etrics?period=total&units=international_system&left_color=grey&right_color=orange&left_text=Downloads)](https://pepy.tech/project/py4etrics)

# What Is This Module For

This module is for
* Truncated Regression
* Tobit Model
* Heckit Model

[Pythonで学ぶ入門計量経済学](https://py4etrics.github.io/) explains how to use it in Japanese. 
Or click its [Google translated version in English](https://translate.google.com/translate?sl=ja&tl=en&u=https%3A%2F%2Fpy4etrics.github.io). 

# How to Use
```
import py4etrics 
```

# How to Install
```
pip install py4etrics
```
or
```
pip install git+https://github.com/spring-haru/py4etrics.git
```
or
```
git clone https://github.com/spring-haru/py4etrics.git
cd py4etrics
pip install .
```

# Thanks
The code is heavily inspired by [statsmodels](https://www.statsmodels.org/stable/index.html).
